from django.template import Context, Template
from django.test import TestCase


class TemplateTagTest(TestCase):
    def test_rendering(self):
        """
        Tests that {{}} tags are well escaped.
        """
        t = Template("""
            {% load i18n templatetag_handlebars %}
            
            {% tplhandlebars "tpl-testing" %}
                {% trans "with translation" %}
                {{name}}
                {{{rawname}}}
                {# works with comments too #}
            {% endtplhandlebars %}
            """)
        c = Context()
        rendered = t.render(c)
        self.failUnless('<script id="tpl-testing" type="text/x-handlebars-template">' in rendered)
        self.failUnless('{{name}}' in rendered)
        self.failUnless('{{{rawname}}}' in rendered)
        self.failUnless('with translation' in rendered)
        # Those should not be rendered :
        self.failUnless('{% trans %}' not in rendered)
        self.failUnless('comments' not in rendered)



import os
from setuptools import setup, find_packages

here = os.path.abspath(os.path.dirname(__file__))

setup(
    name='django-templatetag-handlebars',
    version='1.0',
    author='Mathieu Leplatre',
    author_email='mathieu.leplatre@makina-corpus.com',
    url='https://github.com/makinacorpus/django-templatetag-handlebars',
    download_url = "http://pypi.python.org/pypi/django-templatetag-handlebars/",
    description="Easily embed Handlebars.js templates in your django templates",
    long_description=open(os.path.join(here, 'README.rst')).read(),
    install_requires=[],
    packages=find_packages(),
    classifiers  = ['Topic :: Utilities', 
                    'Natural Language :: English',
                    'Operating System :: OS Independent',
                    'Intended Audience :: Developers',
                    'Environment :: Web Environment',
                    'Framework :: Django',
                    'Development Status :: 5 - Production/Stable',
                    'Programming Language :: Python :: 2.7'],
)
